@@ -3,6 +3,7 @@ import pyperclip
 import argparse
 import io
 
+
 def main():
     parser = argparse.ArgumentParser(
         description='Your clipboard(Excel or Google spreadsheet) change to markdown clipboard',
@@ -17,6 +18,9 @@ def main():
             data = pd.read_clipboard()
         elif args.f == 'csv':
             data = pd.read_csv(io.StringIO(pyperclip.paste()))
+        elif args.f == 'tsv':
+            data = pd.read_csv(io.StringIO(pyperclip.paste()), sep="\t")
+
         print(data.head(3).to_markdown())
         print('......Succeeded!!')
         pyperclip.copy(data.to_markdown())
